@@ -109,6 +109,7 @@ void ball_check_brick_reflection( Ball *b )
 	int reflect;
 	int chaos_reflect;
 	int hit_type;
+    Vector oldBallVel = b->vel;
 
 	/* time left? */
 	if (b->target.cur_tm < b->target.time) return;
@@ -120,7 +121,7 @@ void ball_check_brick_reflection( Ball *b )
 	    (cur_game->extra_active[EX_METAL] && 
 	     cur_game->bricks[b->target.mx][b->target.my].type != MAP_WALL ) )
 		b->idle_time = 0;
-	/* or if it is within the last four rows and no chaotic malus is active it will
+	/* or if it is within the last four rows and no chaotic penalty is active it will
 	   hit the paddle soon so reset here too */
 	if ( b->target.my >= MAP_HEIGHT - 4 && b->vel.y > 0 && !cur_game->extra_active[EX_CHAOS] )
 		b->idle_time = 0;
@@ -137,22 +138,6 @@ void ball_check_brick_reflection( Ball *b )
 	     cur_game->bricks[b->target.mx][b->target.my].type == MAP_BRICK_CHAOS )
 		chaos_reflect = 1;
 
-	/* remove brick -- if weak ball there is a 40% chance that no damage is done to the brick */
-	if ( !cur_game->extra_active[EX_WEAK_BALL] || rand() % 10 < 6 ) {
-		/* if explosive ball und brick is destructible by normal means set as explosive */
-		if ( cur_game->extra_active[EX_EXPL_BALL] )
-		if ( cur_game->bricks[b->target.mx][b->target.my].dur > 0 ) {
-			cur_game->bricks[b->target.mx][b->target.my].type = MAP_BRICK_EXP;
-			cur_game->bricks[b->target.mx][b->target.my].dur = 1;
-		}
-		/* hit brick */
-		hit_type = SHR_BY_NORMAL_BALL;
-		if ( cur_game->extra_active[EX_METAL] ) hit_type = SHR_BY_ENERGY_BALL;
-		brick_hit( b->target.mx, b->target.my, 
-			cur_game->extra_active[EX_METAL], 
-			hit_type, b->vel, b->paddle );
-	}
-
 	/* we have a target and so we have a reset position and even if the ball's
 	   not reflected the position must be reset */
 	b->cur.x = b->target.x; b->x = (int)b->cur.x;
@@ -190,6 +175,22 @@ void ball_check_brick_reflection( Ball *b )
 		b->paddle->last_ball_contact = SDL_GetTicks();
 	}
 	
+	/* remove brick -- if weak ball there is a 40% chance that no damage is done to the brick */
+	if ( !cur_game->extra_active[EX_WEAK_BALL] || rand() % 10 < 6 ) {
+		/* if explosive ball und brick is destructible by normal means set as explosive */
+		if ( cur_game->extra_active[EX_EXPL_BALL] )
+		if ( cur_game->bricks[b->target.mx][b->target.my].dur > 0 ) {
+			cur_game->bricks[b->target.mx][b->target.my].type = MAP_BRICK_EXP;
+			cur_game->bricks[b->target.mx][b->target.my].dur = 1;
+		}
+		/* hit brick */
+		hit_type = SHR_BY_NORMAL_BALL;
+		if ( cur_game->extra_active[EX_METAL] ) hit_type = SHR_BY_ENERGY_BALL;
+		brick_hit( b->target.mx, b->target.my, 
+			cur_game->extra_active[EX_METAL], 
+			hit_type, oldBallVel, b->paddle );
+	}
+
 	/* mark target as disabled so it won't get stuck at the 
 	   bottom of the screen but keep the target position so 
 	   that we know what needs an update. */
@@ -934,7 +935,7 @@ void balls_update( int ms )
 
 		/* check wether no balls are attached and the respawn time is exceeded.
 		 * then in NMP a ball is created and attached */
-		if ( cur_game->game_type == GT_NETWORK && cur_game->level_type == LT_NORMAL )
+		if ( cur_game->game_type == GT_NETWORK && cur_game->level_type != LT_PINGPONG )
 		if ( cur_game->paddles[i]->attached_ball_count == 0 )
 		if ( SDL_GetTicks() >= cur_game->paddles[i]->last_ball_contact + BALL_RESPAWN_TIME ) {
 			x = cur_game->paddles[i]->x + (cur_game->paddles[i]->w - ball_w) / 2;
@@ -1482,7 +1483,7 @@ void ball_get_target( Ball *ball )
 					else
 						prim->side = SIDE_RIGHT;
 #ifdef WITH_BUG_REPORT
-					sprintf( side_str, "Had to change side as TOP wasn't appropiate!" );
+					sprintf( side_str, "Had to change side as TOP wasn't appropriate!" );
 #endif							
 				}
 				break;
@@ -1493,7 +1494,7 @@ void ball_get_target( Ball *ball )
 					else
 						prim->side = SIDE_RIGHT;
 #ifdef WITH_BUG_REPORT
-					sprintf( side_str, "Had to change side as BOTTOM wasn't appropiate!" );
+					sprintf( side_str, "Had to change side as BOTTOM wasn't appropriate!" );
 #endif							
 				}
 				break;
@@ -1504,7 +1505,7 @@ void ball_get_target( Ball *ball )
 					else
 						prim->side = SIDE_BOTTOM;
 #ifdef WITH_BUG_REPORT
-					sprintf( side_str, "Had to change side as LEFT wasn't appropiate!" );
+					sprintf( side_str, "Had to change side as LEFT wasn't appropriate!" );
 #endif							
 				}
 				break;
@@ -1515,7 +1516,7 @@ void ball_get_target( Ball *ball )
 					else
 						prim->side = SIDE_BOTTOM;
 #ifdef WITH_BUG_REPORT
-					sprintf( side_str, "Had to change side as RIGHT wasn't appropiate!" );
+					sprintf( side_str, "Had to change side as RIGHT wasn't appropriate!" );
 #endif							
 				}
 				break;
@@ -1751,4 +1752,3 @@ int balls_detach_from_paddle( Paddle *paddle, int dir )
 	
 	return fired;
 }
-
